#ifndef SHEETW_H
#define SHEETW_H

#include <stddef.h>
#include "setup.h"
#include "handle.h"
#include "enum.h"

#ifdef __cplusplus
extern "C"
{
#endif

    XLAPI            int XLAPIENTRY xlSheetCellTypeW(SheetHandle handle, unsigned short row, unsigned short col);

    XLAPI const wchar_t* XLAPIENTRY xlSheetReadStrW(SheetHandle handle, unsigned short row, unsigned short col, FormatHandle* format);
    XLAPI            int XLAPIENTRY xlSheetWriteStrW(SheetHandle handle, unsigned short row, unsigned short col, const wchar_t* value, FormatHandle format);

    XLAPI         double XLAPIENTRY xlSheetReadNumW(SheetHandle handle, unsigned short row, unsigned short col, FormatHandle* format);
    XLAPI            int XLAPIENTRY xlSheetWriteNumW(SheetHandle handle, unsigned short row, unsigned short col, double value, FormatHandle format);

    XLAPI            int XLAPIENTRY xlSheetReadBoolW(SheetHandle handle, unsigned short row, unsigned short col, FormatHandle* format);
    XLAPI            int XLAPIENTRY xlSheetWriteBoolW(SheetHandle handle, unsigned short row, unsigned short col, int value, FormatHandle format);

    XLAPI            int XLAPIENTRY xlSheetReadBlankW(SheetHandle handle, unsigned short row, unsigned short col, FormatHandle* format);
    XLAPI            int XLAPIENTRY xlSheetWriteBlankW(SheetHandle handle, unsigned short row, unsigned short col, FormatHandle format);

    XLAPI const wchar_t* XLAPIENTRY xlSheetReadCommentW(SheetHandle handle, unsigned short row, unsigned short col);
    XLAPI           void XLAPIENTRY xlSheetWriteCommentW(SheetHandle handle, unsigned short row, unsigned short col, const wchar_t* value, const wchar_t* author, int width, int height);

    XLAPI            int XLAPIENTRY xlSheetIsDateW(SheetHandle handle, unsigned short row, unsigned short col);
    XLAPI            int XLAPIENTRY xlSheetReadErrorW(SheetHandle handle, unsigned short row, unsigned short col);

    XLAPI         double XLAPIENTRY xlSheetColWidthW(SheetHandle handle, unsigned short col);
    XLAPI         double XLAPIENTRY xlSheetRowHeightW(SheetHandle handle, unsigned short row);

    XLAPI            int XLAPIENTRY xlSheetSetColW(SheetHandle handle, unsigned short colFirst, unsigned short colLast, double width, FormatHandle format, int hidden);
    XLAPI            int XLAPIENTRY xlSheetSetRowW(SheetHandle handle, unsigned short row, double height, FormatHandle format, int hidden);

    XLAPI            int XLAPIENTRY xlSheetGetMergeW(SheetHandle handle, unsigned short row, unsigned short col, unsigned short* rowFirst, unsigned short* rowLast, unsigned short* colFirst, unsigned short* colLast);
    XLAPI            int XLAPIENTRY xlSheetSetMergeW(SheetHandle handle, unsigned short rowFirst, unsigned short rowLast, unsigned short colFirst, unsigned short colLast);

    XLAPI           void XLAPIENTRY xlSheetSetPictureW(SheetHandle handle, unsigned short row, unsigned short col, int pictureId, double scale);
    XLAPI           void XLAPIENTRY xlSheetSetPicture2W(SheetHandle handle, unsigned short row, unsigned short col, int pictureId, int width, int height);

    XLAPI            int XLAPIENTRY xlSheetSetHorPageBreakW(SheetHandle handle, unsigned short row, int pageBreak);
    XLAPI            int XLAPIENTRY xlSheetSetVerPageBreakW(SheetHandle handle, unsigned short col, int pageBreak);

    XLAPI           void XLAPIENTRY xlSheetSplitW(SheetHandle handle, unsigned short row, unsigned short col);    

    XLAPI            int XLAPIENTRY xlSheetGroupRowsW(SheetHandle handle, unsigned short rowFirst, unsigned rowLast, int collapsed);
    XLAPI            int XLAPIENTRY xlSheetGroupColsW(SheetHandle handle, unsigned short colFirst, unsigned colLast, int collapsed);

    XLAPI           void XLAPIENTRY xlSheetClearW(SheetHandle handle, unsigned short rowFirst, unsigned short rowLast, unsigned short colFirst, unsigned short colLast);

    XLAPI unsigned short XLAPIENTRY xlSheetFirstRowW(SheetHandle handle);
    XLAPI unsigned short XLAPIENTRY xlSheetLastRowW(SheetHandle handle);
    XLAPI unsigned short XLAPIENTRY xlSheetFirstColW(SheetHandle handle);
    XLAPI unsigned short XLAPIENTRY xlSheetLastColW(SheetHandle handle);

    XLAPI            int XLAPIENTRY xlSheetDisplayGridlinesW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetDisplayGridlinesW(SheetHandle handle, int show);

    XLAPI            int XLAPIENTRY xlSheetPrintGridlinesW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetPrintGridlinesW(SheetHandle handle, int print);

    XLAPI       unsigned XLAPIENTRY xlSheetZoomW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetZoomW(SheetHandle handle, unsigned zoom);

    XLAPI       unsigned XLAPIENTRY xlSheetPrintZoomW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetPrintZoomW(SheetHandle handle, unsigned zoom);

    XLAPI            int XLAPIENTRY xlSheetLandscapeW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetLandscapeW(SheetHandle handle, int landscape);

    XLAPI            int XLAPIENTRY xlSheetPaperW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetPaperW(SheetHandle handle, int paper);

    XLAPI const wchar_t* XLAPIENTRY xlSheetHeaderW(SheetHandle handle);
    XLAPI            int XLAPIENTRY xlSheetSetHeaderW(SheetHandle handle, const wchar_t* header, double margin);
    XLAPI         double XLAPIENTRY xlSheetHeaderMarginW(SheetHandle handle);

    XLAPI const wchar_t* XLAPIENTRY xlSheetFooterW(SheetHandle handle);
    XLAPI            int XLAPIENTRY xlSheetSetFooterW(SheetHandle handle, const wchar_t* footer, double margin);
    XLAPI         double XLAPIENTRY xlSheetFooterMarginW(SheetHandle handle);

    XLAPI            int XLAPIENTRY xlSheetHCenterW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetHCenterW(SheetHandle handle, int hCenter);

    XLAPI            int XLAPIENTRY xlSheetVCenterW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetVCenterW(SheetHandle handle, int vCenter);

    XLAPI         double XLAPIENTRY xlSheetMarginLeftW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetMarginLeftW(SheetHandle handle, double margin);

    XLAPI         double XLAPIENTRY xlSheetMarginRightW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetMarginRightW(SheetHandle handle, double margin);

    XLAPI         double XLAPIENTRY xlSheetMarginTopW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetMarginTopW(SheetHandle handle, double margin);

    XLAPI         double XLAPIENTRY xlSheetMarginBottomW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetMarginBottomW(SheetHandle handle, double margin);

    XLAPI            int XLAPIENTRY xlSheetPrintRowColW(SheetHandle handle);
    XLAPI           void XLAPIENTRY xlSheetSetPrintRowColW(SheetHandle handle, int print);

    XLAPI const wchar_t* XLAPIENTRY xlSheetNameW(SheetHandle handle);

#ifdef __cplusplus
}
#endif

#endif
