#ifndef IBOOKT_H
#define IBOOKT_H

#include <stddef.h>
#include "setup.h"

namespace libxl {

    template<class TCHAR> struct ISheetT;
    template<class TCHAR> struct IFormatT;
    template<class TCHAR> struct IFontT;

    template<class TCHAR>
    struct IBookT  
    {
        virtual             bool XLAPIENTRY load(const TCHAR* filename) = 0; 
        virtual             bool XLAPIENTRY save(const TCHAR* filename) = 0; 

        virtual  ISheetT<TCHAR>* XLAPIENTRY addSheet(const TCHAR* name) = 0; 
        virtual  ISheetT<TCHAR>* XLAPIENTRY getSheet(unsigned short index) const = 0; 
        virtual             bool XLAPIENTRY delSheet(unsigned short index) = 0; 
        virtual   unsigned short XLAPIENTRY sheetCount() const = 0;  

        virtual IFormatT<TCHAR>* XLAPIENTRY addFormat(IFormatT<TCHAR>* initFormat = 0) = 0; 
        virtual   IFontT<TCHAR>* XLAPIENTRY addFont(IFontT<TCHAR>* initFont = 0) = 0; 
        virtual         unsigned XLAPIENTRY addCustomNumFormat(const TCHAR* customNumFormat) = 0;
        virtual     const TCHAR* XLAPIENTRY customNumFormat(unsigned fmt) const = 0;

        virtual           double XLAPIENTRY datePack(unsigned short year, unsigned short month, unsigned short day,
                                                     unsigned short hour = 0, unsigned short min = 0, unsigned short sec = 0) = 0;

        virtual             bool XLAPIENTRY dateUnpack(double value, unsigned short* year, unsigned short* month, unsigned short* day,
                                                                     unsigned short* hour = 0, unsigned short* min = 0, unsigned short* sec = 0) = 0;

        virtual   unsigned short XLAPIENTRY activeSheet() const = 0;
        virtual             void XLAPIENTRY setActiveSheet(unsigned short index) = 0;

        virtual              int XLAPIENTRY addPicture(const TCHAR* filename) = 0;

        virtual             void XLAPIENTRY setKey(const wchar_t* name, const wchar_t* key) = 0; 
        virtual             void XLAPIENTRY setLocale(const char* locale) = 0;
        virtual      const char* XLAPIENTRY errorMessage() const = 0;    

        virtual             void XLAPIENTRY release() = 0;    
    };

}

extern "C" XLAPI libxl::IBookT<char>* XLAPIENTRY xlCreateBookA();
extern "C" XLAPI libxl::IBookT<wchar_t>* XLAPIENTRY xlCreateBookW();

#endif
